.. _spkg_sagemath_gsl:

===============================================================================
sagemath_gsl: Numerics with the GNU Scientific Library
===============================================================================


This pip-installable distribution ``passagemath-gsl`` is a distribution of a part of the Sage Library.  It provides a subset of the modules of the Sage library ("sagelib", ``passagemath-standard``) that depend on the GNU Scientific Library.


What is included
----------------

* `Numerical Integration - Symbolic Calculus <https://passagemath.org/docs/latest/html/en/reference/calculus/sage/calculus/integration.html>`__

* `Discrete Wavelet Transform - Symbolic Calculus <https://passagemath.org/docs/latest/html/en/reference/calculus/sage/calculus/transforms/dwt.html>`__

* `Discrete Fourier Transforms - Symbolic Calculus <https://passagemath.org/docs/latest/html/en/reference/calculus/sage/calculus/transforms/dft.html>`__

* `Fast Fourier Transforms Using GSL - Symbolic Calculus <https://passagemath.org/docs/latest/html/en/reference/calculus/sage/calculus/transforms/fft.html>`__

* `Riemann Mapping - Symbolic Calculus <https://passagemath.org/docs/latest/html/en/reference/calculus/sage/calculus/riemann.html>`__

* `Solving ODE numerically by GSL - Symbolic Calculus <https://passagemath.org/docs/latest/html/en/reference/calculus/sage/calculus/ode.html>`__

* `Real Interpolation using GSL - Symbolic Calculus <https://passagemath.org/docs/latest/html/en/reference/calculus/sage/calculus/interpolation.html>`__

* `Probability Spaces and Distributions <https://passagemath.org/docs/latest/html/en/reference/probability/index.html>`_


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cysignals`
- :ref:`spkg_cython`
- :ref:`spkg_gmp`
- :ref:`spkg_gsl`
- :ref:`spkg_jinja2`
- :ref:`spkg_memory_allocator`
- :ref:`spkg_mpc`
- :ref:`spkg_mpfr`
- :ref:`spkg_numpy`
- :ref:`spkg_pkgconf`
- :ref:`spkg_pkgconfig`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_categories`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_sagemath_modules`
- :ref:`spkg_setuptools`

Version Information
-------------------

package-version.txt::

    10.8.2.rc1

version_requirements.txt::

    passagemath-gsl == 10.8.2rc1

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install passagemath-gsl==10.8.2rc1

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sagemath_gsl


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
